#!/bin/sh
cea_exit()
{
  echo "$1" >> $CEA_GENACT_DEBUG_LOG
  echo "(`date`) CeA/ExtendIT Debug Log finished by $SCRIPTNAME on `hostname` (`uname`) after FAILED collect.">>${CEA_GENACT_DEBUG_LOG}
  exit $2
} 

get_users()
{
  GET_ALL_LDAP_USERS="${CEA_LSUSER} -R LDAP -a id gecos ALL"
  ${GET_ALL_LDAP_USERS}>${PROPSFILE}_uid 2>>${CEA_GENACT_DEBUG_LOG}
  [[ $? -ne 0 ]] && cea_exit "Error executing (${GET_ALL_LDAP_USERS})." "101"
  
  LINE_SHIFT=`wc -l ${PROPSFILE}_uid | sed -e 's/^ *\([0-9]\{1,\}\).*/\1/'`  

  echo [Persons]>${TEMPFILE}
  i=1
  while [ $i -le $LINE_SHIFT ]
  do
    record=`sed -n -e ${i}p ${PROPSFILE}_uid`     
    username=`echo ${record}|sed -e "s/^\(.*\) id=.*/\1/"`
    realname=`echo ${record}|grep gecos|sed -e "s/^.* id=.* gecos=\(.*\)/\1/"`
    if [ -z "${realname}" ] 
    then
      realname=${username}
      userid=`echo ${record}|sed -e "s/^.* id=\(.*\)/\1/"`  
    else  
      userid=`echo ${record}|sed -e "s/^.* id=\(.*\) gecos=.*/\1/"`  
    fi
    
    echo \"${username}\" \""${realname}"\" \"0\">>${TEMPFILE}
    echo "{">>${TEMPFILE}
    echo "  match logonname \"${username}\"">>${TEMPFILE}
    echo "  match originator \"${userid}\"">>${TEMPFILE}
    echo "}">>${TEMPFILE}
  
    i=$((i+1))
  done
  
  rm ${PROPSFILE}_uid
}

get_user_id()
{
  uid=`${CEA_LSUSER} -R ${2} -a id ${1}|sed -e "s/^.* id=\(.*\)/\1/"`
  echo $uid
}

get_groups()
{
  GET_ALL_LDAP_GROUPS="${CEA_LSGROUP} -R LDAP -a users ALL"
  ${GET_ALL_LDAP_GROUPS}>${PROPSFILE}_gid 2>>${CEA_GENACT_DEBUG_LOG}
  [[ $? -ne 0 ]] && cea_exit "Error executing (${GET_ALL_LDAP_GROUPS})." "102"

  LINE_SHIFT=`wc -l ${PROPSFILE}_gid | sed -e 's/^ *\([0-9]\{1,\}\).*/\1/'`  

  echo [SourceGroup]>>${TEMPFILE}
  i=1
  while [ $i -le $LINE_SHIFT ]
  do
    record=`sed -n -e ${i}p ${PROPSFILE}_gid`     
    groupname=`echo ${record}|sed -e "s/^\(.*\) users=.*/\1/"`
    users=`echo ${record}|sed -e "s/^.* users=\(.*\)/\1/"|tr ',' ' '`

    echo \"${groupname}\">>${TEMPFILE}
    for aa in ${users}
    do
      uid=`get_user_id ${aa} LDAP`
      if [ -z "${uid}" ] 
      then
        uid=`get_user_id ${aa} compat`
      fi
      if [ ! -z "${uid}" ] 
      then
        echo "{">>${TEMPFILE}
        echo "  match logonname \"${aa}\"">>${TEMPFILE}
        echo "  match originator \"${uid}\"">>${TEMPFILE}
        echo "}">>${TEMPFILE}
      fi
    done
    i=$((i+1))
  done
  
  rm ${PROPSFILE}_gid
}

get_roles()
{
  GET_ALL_LDAP_USERS="${CEA_LSUSER} -R LDAP -a id roles ALL"
  ${GET_ALL_LDAP_USERS}>${PROPSFILE}_rid 2>>${CEA_GENACT_DEBUG_LOG}
  [[ $? -ne 0 ]] && cea_exit "Error executing (${GET_ALL_LDAP_USERS})." "103"

  LINE_SHIFT=`wc -l ${PROPSFILE}_rid | sed -e 's/^ *\([0-9]\{1,\}\).*/\1/'`  
  i=1
  while [ $i -le $LINE_SHIFT ]
  do
    record=`sed -n -e ${i}p ${PROPSFILE}_rid|grep roles`     
    username=`echo ${record}|sed -e "s/^\(.*\) id=.*/\1/"`
    userid=`echo ${record}|sed -e "s/^.* id=\(.*\) roles=.*/\1/"`
    roles=`echo ${record}|sed -e "s/^.* id=.* roles=\(.*\)/\1/"|tr ',' ' '`
  
    if [ ! -z "${roles}" ] 
    then
      for aa in ${roles}
      do
        echo \"${aa} role\">>${TEMPFILE}
        echo "{">>${TEMPFILE}
        echo "  match logonname \"${username}\"">>${TEMPFILE}
        echo "  match originator \"${userid}\"">>${TEMPFILE}
        echo "}">>${TEMPFILE}
      done
     fi
    i=$((i+1))
  done
  
  rm ${PROPSFILE}_rid

}

SCRIPTNAME=$0

if [ $# -ge 3 ]
then
  :
else
  echo "$0: Insufficient number of arguments. Usage: $0 output_file grouping_file property_file." 1>&2
  exit 1
fi

TEMPFILE=$1
eval PROPSFILE=\$$#
CEA_GENACT_DEBUG_LOG=../log/${PROPSFILE}.log
CEA_LSUSER="/usr/sbin/lsuser"
CEA_LSGROUP="/usr/sbin/lsgroup"

echo "(`date`) CeA/ExtendIT Debug Log created by $SCRIPTNAME on `hostname` (`uname`).">${CEA_GENACT_DEBUG_LOG}
echo "(`date`) Retrieving the user information...">>${CEA_GENACT_DEBUG_LOG}
get_users
echo "(`date`) Retrieving the usergroup information...">>${CEA_GENACT_DEBUG_LOG}
get_groups
echo "(`date`) Retrieving the administrative roles information...">>${CEA_GENACT_DEBUG_LOG}
get_roles
echo "(`date`) CeA/ExtendIT Debug Log finished by $SCRIPTNAME on `hostname` (`uname`) after SUCCESSFUL collect.">>${CEA_GENACT_DEBUG_LOG}
