#!/bin/ksh
export LC_TIME="C"
PROPS_FILE=$PROPSFILE
CEA_GENACT_DEBUG_LOG=../log/${PROPSFILE}.log
. $CEA_GENACT_FUNCLIB || return 1

echo "" > $CEA_GENACT_DEBUG_LOG
# checking input parameters 

if [ "a$TEMPFILE1" = "a" ] ; then 
 echo `date "+%a %D %T"` FAILURE. Sublog name is not defined. >> $CEA_GENACT_DEBUG_LOG 
 exit 1
fi

if [ "a$OPTION2" != "a" ] ; then 
 INST_NAME=$OPTION2
 INST_HOME=`cat /etc/passwd | grep "^$INST_NAME:" | sed -e "s/^$INST_NAME:[^:]*:[^:]*:[^:]*:[^:]*:\([^:]*\):[^:]*/\1/"`
  if [ ! $? -eq 0 ] ; then
   echo `date "+%a %D %T"` FAILURE. Error reading /etc/passwd file. >> $CEA_GENACT_DEBUG_LOG
   return 1
  fi  
else
 echo `date "+%a %D %T"` FAILURE. Instance name is not defined. >> $CEA_GENACT_DEBUG_LOG 
 exit 1
fi

if [ "a$OPTION3" != "a" ] ; then 
 DATABASE_NAME=$OPTION3
else
 echo `date "+%a %D %T"` FAILURE. Database name is not defined. >> $CEA_GENACT_DEBUG_LOG 
 exit 1
fi

if [ "a$OPTION4" != "a" ] ; then 
 DB2_SCHEMA=$OPTION4
else
 echo `date "+%a %D %T"` FAILURE. Database schema is not defined. >> $CEA_GENACT_DEBUG_LOG 
 exit 1
fi

if [ "a$OPTION5" != "a" ] ; then 
 USER_NAME=$OPTION5
else
 echo `date "+%a %D %T"` Username is not defined. Using current user. >> $CEA_GENACT_DEBUG_LOG 
fi

if [ "a$OPTION6" != "a" ] ; then 
 PASSWORD=$OPTION6
else
 if [ "a$USER_NAME" != "a" ] ; then
 echo `date "+%a %D %T"` FAILURE. Password is not defined. >> $CEA_GENACT_DEBUG_LOG 
 exit 1
 fi
fi

if [ "a$PROPS_FILE" = "a" ] ; then 
 echo `date "+%a %D %T"` PROPS_FILE parameter is not defined. Exiting. >> $CEA_GENACT_DEBUG_LOG 
 exit 1
fi
 
# initializing internal variables
CURRENT_DIR=`pwd`
TEMP_DIR="$CURRENT_DIR/$PROPS_FILE.dir"
TEMP_FILE_RAW=$TEMP_DIR/raw.txt
TEMP_FILE_HEADLINE=$TEMP_DIR/headline.txt
#creating temporary directory
rm -rf $TEMP_DIR
mkdir $TEMP_DIR
 

echo `date "+%a %D %T"` Starting collect and setting environment variables. >> $CEA_GENACT_DEBUG_LOG
/bin/ksh -c ". $CEA_GENACT_FUNCLIB; testrights "$INST_HOME/sqllib/db2profile" "RX" 2>> $CEA_GENACT_DEBUG_LOG"
ERRORCODE=$?
if [ $ERRORCODE -eq 0 ] ; then
. $INST_HOME/sqllib/db2profile
 if [ ! $? -eq 0 ] ; then
  echo `date "+%a %D %T"` FAILURE. Error setting environment variables. Error code $ERRORCODE.>> $CEA_GENACT_DEBUG_LOG 
 exit 1
 fi
else 
 echo `date "+%a %D %T"` FAILURE. DB2 instance isn\'t available. Error code $ERRORCODE. >> $CEA_GENACT_DEBUG_LOG
 exit 1
fi
 
/bin/ksh -c ". $CEA_GENACT_FUNCLIB; testrights "$INST_HOME/sqllib/bin/db2" "RX" 2>> $CEA_GENACT_DEBUG_LOG"
ERRORCODE=$?
if [ $ERRORCODE -eq 0 ] ; then
 echo `date "+%a %D %T"` Connecting to the database $DATABASE_NAME. >> $CEA_GENACT_DEBUG_LOG
 if [ "a$USER_NAME" != "a" ] ; then
  DB2_CONNECT="$INST_HOME/sqllib/bin/db2 CONNECT TO $DATABASE_NAME USER $USER_NAME USING $PASSWORD"
  #echo `date "+%a %D %T"` `$DB2_CONNECT` >> $CEA_GENACT_DEBUG_LOG
  $DB2_CONNECT >> $CEA_GENACT_DEBUG_LOG
  ERRORCODE=$?
 else
  DB2_CONNECT="$INST_HOME/sqllib/bin/db2 CONNECT TO $DATABASE_NAME"
  #echo `date "+%a %D %T"` `$DB2_CONNECT` >> $CEA_GENACT_DEBUG_LOG
  $DB2_CONNECT >> $CEA_GENACT_DEBUG_LOG
  ERRORCODE=$?
 fi
 if [ ! $ERRORCODE -eq 0 ] ; then
  echo `date "+%a %D %T"` FAILURE. Error connecting to the database $DATABASE_NAME.>> $CEA_GENACT_DEBUG_LOG 
  exit 1
 fi
else
 echo `date "+%a %D %T"` FAILURE. Unable to call DB2 CLP. >> $CEA_GENACT_DEBUG_LOG
 exit 1
fi

ADHEVENT_FIELDS="adhevent.tuid, ';',adhevent.action_tuid, ';',adhevent.target_tuid, ';',adhevent.user_tuid, ';',adhevent.time, ';',adhevent.result, ';',adhevent.source_tuid, ';',adhevent.detail_tuid, ';',adhevent.corr_id, ';',adhevent.source_detail_tuid, ';',adhevent.authchange_tuid, ';' "
ADHEVENT_ACTION_FIELDS="adhevent_action.agent_id, ';', adhevent_action.category, ';', adhevent_action.event_type, ';', adhevent_action.context_type, ';' "
ADHEVENT_USER_FIELDS="adhevent_user.user_id, ';',adhevent_user.authorization_id, ';',adhevent_user.original_op_id, ';',adhevent_user.account_token, ';',adhevent_user.end_user_id, ';',adhevent_user.end_usr_trans_name, ';',adhevent_user.end_usr_wkstn_name, ';' "
ADHEVENT_TARGET_FIELDS="adhevent_target.container, ';' ,adhevent_target.xschema, ';' ,adhevent_target.name, ';' ,adhevent_target.type, ';' ,adhevent_target.new_sqlid, ';', adhevent_target.database_id, ';' "
ADHEVENT_SRC_FIELDS="adhevent_src.xdatabase, ';', adhevent_src.app_id, ';', adhevent_src.app_name, ';', adhevent_src.origin_node_num, ';', adhevent_src.corr_node_num, ';', adhevent_src.db2_subsystem_id, ';', adhevent_src.location, ';', adhevent_src.network_id, ';', adhevent_src.luname, ';', adhevent_src.corr_id, ';', adhevent_src.connection_name, ';', adhevent_src.system_con_type, ';', adhevent_src.requestor_location, ';', adhevent_src.requestor_svr_name, ';', adhevent_src.requestor_prod_id, ';', adhevent_src.member_name, ';', adhevent_src.group_name, ';', adhevent_src.current_sqlid, ';' "
ADHEVENT_DTAIL_FIELDS="adhevent_dtail.approval_reason, ';', adhevent_dtail.access_attempted, ';', adhevent_dtail.grantor, ';', adhevent_dtail.grantee, ';', adhevent_dtail.grant_type, ';', adhevent_dtail.priv_auth, ';', adhevent_dtail.auth_type, ';', adhevent_dtail.plugin_name, ';', adhevent_dtail.utility_info, ';' "
ADHAGENT_FIELDS="adhagent.name, ';', adhagent.user_id, ';', adhagent.system, ';', adhagent.subsystem, ';', adhagent.port, ';', adhagent.connect_type, ';', adhagent.session_id"
FROM="$DB2_SCHEMA.adhevent AS adhevent, $DB2_SCHEMA.adhevent_action AS adhevent_action, $DB2_SCHEMA.adhevent_user AS adhevent_user, $DB2_SCHEMA.adhevent_target AS adhevent_target, $DB2_SCHEMA.adhevent_src AS adhevent_src, $DB2_SCHEMA.adhevent_dtail AS adhevent_dtail, $DB2_SCHEMA.adhagent AS adhagent"
#====
if [ ! -f $PROPS_FILE ] ; then
 WHERE="adhevent.action_tuid=adhevent_action.tuid AND adhevent.user_tuid=adhevent_user.tuid AND adhevent.target_tuid=adhevent_target.tuid AND adhevent.source_tuid=adhevent_src.tuid AND adhevent.detail_tuid=adhevent_dtail.tuid AND adhagent.tuid = adhevent_action.agent_id AND adhevent.time > CURRENT_TIMESTAMP - 2 DAY ORDER BY adhevent.tuid"
else
 PREVIOUS_TUID=`head -1 $PROPS_FILE`
 if [ "$PREVIOUS_TUID" = "-1" ] ; then
  ADHEVENT_TIME=`tail -1 $PROPS_FILE`
  WHERE="adhevent.action_tuid=adhevent_action.tuid AND adhevent.user_tuid=adhevent_user.tuid AND adhevent.target_tuid=adhevent_target.tuid AND adhevent.source_tuid=adhevent_src.tuid AND adhevent.detail_tuid=adhevent_dtail.tuid AND adhagent.tuid = adhevent_action.agent_id AND adhevent.time > '$ADHEVENT_TIME' ORDER BY adhevent.tuid"
  else
   WHERE="adhevent.action_tuid=adhevent_action.tuid AND adhevent.user_tuid=adhevent_user.tuid AND adhevent.target_tuid=adhevent_target.tuid AND adhevent.source_tuid=adhevent_src.tuid AND adhevent.detail_tuid=adhevent_dtail.tuid AND adhagent.tuid = adhevent_action.agent_id AND adhevent.tuid > $PREVIOUS_TUID ORDER BY adhevent.tuid"
  fi
fi
#====
echo "SELECT $ADHEVENT_FIELDS, $ADHEVENT_ACTION_FIELDS, $ADHEVENT_USER_FIELDS, $ADHEVENT_TARGET_FIELDS, $ADHEVENT_SRC_FIELDS, $ADHEVENT_DTAIL_FIELDS, $ADHAGENT_FIELDS FROM $FROM WHERE $WHERE"  > $TEMP_DIR/$PROPS_FILE.sql

 
echo `date "+%a %D %T"` Performing SQL-query. >> $CEA_GENACT_DEBUG_LOG
#echo "#Fields:ADHEVENT.TUID;ADHEVENT.ACTION_TUID;ADHEVENT.TARGET_TUID;ADHEVENT.USER_TUID;ADHEVENT.TIME;ADHEVENT.RESULT;ADHEVENT.SOURCE_TUID;DETAIL_TUID;ADHEVENT.CORR_ID;ADHEVENT.SOURCE_DETAIL_TUID;ADHEVENT.AUTHCHANGE_TUID;ADHEVENT_ACTION.AGENT_ID;ADHEVENT_ACTION.CATEGORY;ADHEVENT_ACTION.EVENT_TYPE;ADHEVENT_ACTION.CONTEXT_TYPE;ADHEVENT_USER.USER_ID;ADHEVENT_USER.AUTHORIZATION_ID;ADHEVENT_USER.ORIGINAL_OP_ID;ADHEVENT_USER.ACCOUNT_TOKEN;ADHEVENT_USER.END_USER_ID;ADHEVENT_USER.END_USR_TRANS_NAME;ADHEVENT_USER.END_USR_WKSTN_NAME;ADHEVENT_TARGET.CONTAINER;ADHEVENT_TARGET.XSCHEMA;ADHEVENT_TARGET.NAME;ADHEVENT_TARGET.TYPE;ADHEVENT_TARGET.NEW_SQLID;ADHEVENT_TARGET.DATABASE_ID;ADHEVENT_SRC.XDATABASE;ADHEVENT_SRC.APP_ID;ADHEVENT_SRC.APP_NAME;ADHEVENT_SRC.ORIGIN_NODE_NUM;ADHEVENT_SRC.CORR_NODE_NUM;ADHEVENT_SRC.DB2_SUBSYSTEM_ID;ADHEVENT_SRC.LOCATION;ADHEVENT_SRC.NETWORK_ID;ADHEVENT_SRC.LUNAME;ADHEVENT_SRC.CORR_ID;ADHEVENT_SRC.CONNECTION_NAME;ADHEVENT_SRC.SYSTEM_CON_TYPE;ADHEVENT_SRC.REQUESTOR_LOCATION;ADHEVENT_SRC.REQUESTOR_SVR_NAME;ADHEVENT_SRC.REQUESTOR_PROD_ID;ADHEVENT_SRC.MEMBER_NAME;ADHEVENT_SRC.GROUP_NAME;ADHEVENT_SRC.CURRENT_SQLID;ADHEVENT_DTAIL.APPROVAL_REASON;ADHEVENT_DTAIL.ACCESS_ATTEMPTED;ADHEVENT_DTAIL.GRANTOR;ADHEVENT_DTAIL.GRANTEE;ADHEVENT_DTAIL.GRANT_TYPE;ADHEVENT_DTAIL.PRIV_AUTH;ADHEVENT_DTAIL.AUTH_TYPE;ADHEVENT_DTAIL.PLUGIN_NAME;ADHEVENT_DTAIL.UTILITY_INFO;ADHAGENT.NAME;ADHAGENT.USER_ID;ADHAGENT.SYSTEM;ADHAGENT.SUBSYSTEM;ADHAGENT.PORT;ADHAGENT.CONNECT_TYPE;ADHAGENT.SESSION_ID" > $TEMPFILE1

echo "#Fields:  TUID;ACTION_TUID;TARGET_TUID;USER_TUID;TIME;RESULT;SOURCE_TUID;DETAIL_TUID;CORR_ID;SOURCE_DETAIL_TUID;AUTHCHANGE_TUID;AGENT_ID;CATEGORY;EVENT_TYPE;CONTEXT_TYPE;USER_ID;AUTHORIZATION_ID;ORIGINAL_OP_ID;ACCOUNT_TOKEN;END_USER_ID;END_USR_TRANS_NAME;END_USR_WKSTN_NAME;CONTAINER;XSCHEMA;NAME;TYPE;NEW_SQLID;DATABASE_ID;XDATABASE;APP_ID;APP_NAME;ORIGIN_NODE_NUM;CORR_NODE_NUM;DB2_SUBSYSTEM_ID;LOCATION;NETWORK_ID;LUNAME;CORR_ID_1;CONNECTION_NAME;SYSTEM_CON_TYPE;REQUESTOR_LOCATION;REQUESTOR_SVR_NAME;REQUESTOR_PROD_ID;MEMBER_NAME;GROUP_NAME;CURRENT_SQLID;APPROVAL_REASON;ACCESS_ATTEMPTED;GRANTOR;GRANTEE;GRANT_TYPE;PRIV_AUTH;AUTH_TYPE;PLUGIN_NAME;UTILITY_INFO;NAME_1;USER_ID_1;SYSTEM;SUBSYSTEM;PORT;CONNECT_TYPE;SESSION_ID" > $TEMPFILE1

$INST_HOME/sqllib/bin/db2 -xnf "$TEMP_DIR/$PROPS_FILE.sql" >> $TEMPFILE1 
ERRORCODE=$?

if [ ! $ERRORCODE -eq 0  -a ! $ERRORCODE -eq 1 ] ; then
 tail -2 $TEMPFILE1 >> $CEA_GENACT_DEBUG_LOG
 echo `date "+%a %D %T"` FAILURE. Error running query. Error code $ERRORCODE.>> $CEA_GENACT_DEBUG_LOG 
 exit 1
fi

echo `date "+%a %D %T"` Creating Creating properties file. >> $CEA_GENACT_DEBUG_LOG
TUID=`tail -2 $TEMPFILE1 | head -n 1 | grep ';' | grep -v TUID | cut -f1 -d ';' | sed 's/ *//'`
if [ "a$TUID" != "a" ] ; then 
 echo $TUID > $PROPS_FILE
 date "+%Y-%m-%d-%H.%M.%S.000000" >> $PROPS_FILE
else
 if [ "a$PREVIOUS_TUID" = "a" ] ; then
  echo "-1" > $PROPS_FILE
  date "+%Y-%m-%d-%H.%M.%S.000000" >> $PROPS_FILE
 else
  echo $PREVIOUS_TUID > $PROPS_FILE
  date "+%Y-%m-%d-%H.%M.%S.000000" >> $PROPS_FILE
 fi
fi
 
echo `date "+%a %D %T"` Creating output file. >> $CEA_GENACT_DEBUG_LOG

echo `date "+%a %D %T"` Disconnecting from the database $DATABASE_NAME. >> $CEA_GENACT_DEBUG_LOG    
echo `date "+%a %D %T"` `$INST_HOME/sqllib/bin/db2 terminate` >> $CEA_GENACT_DEBUG_LOG 
ERRORCODE=$?
if [ ! $ERRORCODE -eq 0 ] ; then
 echo `date "+%a %D %T"` FAILURE. Error disconnecting from the database. Error code $ERRORCODE.>> $CEA_GENACT_DEBUG_LOG 
 exit 1
fi
echo `date "+%a %D %T"` SUCCESS. Collect finished. >> $CEA_GENACT_DEBUG_LOG
 

rm -rf $TEMP_DIR
exit 0
