#!/bin/sh

######################################################################
# export all envinroment variables which are needed for getoradblogs2.sh back-end actuator script     #
######################################################################
export_env_variables()
{
    export PROPSFILE
    export CEA_GENACT_FUNCLIB
    export CEA_GENACT_DEBUG_LOG

    export ORACLE_SID
    export ORA_INSTANCE
    export ORA_USER
    export ORA_PWD
    export ORACLE_HOME 

    export TEMPFILE

    export TABLE_NAME
    export TABLE_NAME9
    export TABLE_NAME10
    export TABLE_DESC
    export TABLE_DESC9
    export TABLE_DESC10
    export TABLE_HEAD
    export TABLE_HEAD9
    export TABLE_HEAD10
    export COL_TIME
    export COL_TIME9
    export COL_TIME10
    export LINE_SIZE
    export GETHEADER
    export PARAM_OUTPUT
    export NOTIMESTAMP
    export TIMESTAMPNAME
    export NOLINESCHECK
}


# Source our function library. It contains generic functions. 
. $CEA_GENACT_FUNCLIB || exit 1

#######################################################
# Usage: err_exit <exit-code> [exit-message]
#######################################################
err_exit()
{
  debug $2
  debug "Warning: Processing finished with error \"$1\". "
  exit 0
}

CEA_GENACT_DEBUG_LOG="../log/cea_genact_debug_log.log"

if [ -z "${PROPSFILE}" ]; then err_exit 1 "Properties file must be specified!"; fi
CEA_GENACT_DEBUG_LOG="../log/${PROPSFILE}.log"
debug script $0 is running

if [ -z "${OPTION2}" ]; then err_exit 1 "Option #2 'Oracle Instance' must be specified!"; fi
if [ -z "${OPTION3}" ]; then err_exit 1 "Option #3 'Oracle User Name' must be specified!"; fi
if [ -z "${OPTION5}" ]; then err_exit 1 "Option #5 'Oracle Home Path' must be specified!"; fi

# Parameters needed for oracle access
ORACLE_SID="${OPTION2}"
ORA_INSTANCE="@${OPTION2}"
ORA_USER="${OPTION3}"
ORA_PWD="${OPTION4}"
ORACLE_HOME="${OPTION5}"

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE5}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_concurrent_requests fcr LEFT OUTER JOIN applsys.fnd_logins fl ON fcr.conc_login_id=fl.login_id 
LEFT OUTER JOIN applsys.fnd_user fu ON fcr.requested_by=fu.user_id 
LEFT OUTER JOIN applsys.fnd_application_tl fat ON fcr.program_application_id=fat.application_id and fat.language in 
(select LANGUAGE_CODE from APPLSYS.FND_LANGUAGES where INSTALLED_FLAG = 'B') 
LEFT OUTER JOIN applsys.fnd_concurrent_programs_tl fcpt ON fcpt.concurrent_program_id=fcr.concurrent_program_id and 
fcr.program_application_id=fcpt.application_id and fcpt.language in 
(select LANGUAGE_CODE from APPLSYS.FND_LANGUAGES where INSTALLED_FLAG = 'B')"
TABLE_DESC9="fcr.REQUEST_ID,fcr.LAST_UPDATE_DATE,fcr.LAST_UPDATED_BY,fcr.LAST_UPDATE_LOGIN,fcr.REQUEST_DATE,fcr.REQUESTED_BY,
fcr.PHASE_CODE,fcr.STATUS_CODE,fcr.PRIORITY_REQUEST_ID,fcr.PRIORITY,fcr.REQUESTED_START_DATE,fcr.HOLD_FLAG,
fcr.ENFORCE_SERIALITY_FLAG,fcr.SINGLE_THREAD_FLAG,fcr.HAS_SUB_REQUEST,fcr.IS_SUB_REQUEST,fcr.IMPLICIT_CODE,
fcr.UPDATE_PROTECTED,fcr.QUEUE_METHOD_CODE,fcr.ARGUMENT_INPUT_METHOD_CODE,fcr.ORACLE_ID,fcr.PROGRAM_APPLICATION_ID,
fcr.CONCURRENT_PROGRAM_ID,fcr.RESPONSIBILITY_APPLICATION_ID,fcr.RESPONSIBILITY_ID,fcr.NUMBER_OF_ARGUMENTS,
fcr.NUMBER_OF_COPIES,fcr.SAVE_OUTPUT_FLAG,fcr.NLS_LANGUAGE,fcr.NLS_TERRITORY,fcr.PRINTER,fcr.PRINT_STYLE,
fcr.PRINT_GROUP,fcr.REQUEST_CLASS_APPLICATION_ID,fcr.CONCURRENT_REQUEST_CLASS_ID,fcr.PARENT_REQUEST_ID,
fcr.CONC_LOGIN_ID,fcr.LANGUAGE_ID,replace(fcr.DESCRIPTION,CHR(10),' ') as DESCRIPTION,
replace(fcr.REQ_INFORMATION,CHR(10),' ') as REQ_INFORMATION,fcr.RESUBMIT_INTERVAL,
fcr.RESUBMIT_INTERVAL_UNIT_CODE,fcr.RESUBMIT_INTERVAL_TYPE_CODE,fcr.RESUBMIT_TIME,fcr.RESUBMIT_END_DATE,
fcr.RESUBMITTED,fcr.CONTROLLING_MANAGER,fcr.ACTUAL_START_DATE,fcr.ACTUAL_COMPLETION_DATE,
replace(fcr.COMPLETION_TEXT,CHR(10),' ') as COMPLETION_TEXT,replace(fcr.OUTCOME_PRODUCT,CHR(10),' ') as OUTCOME_PRODUCT,
fcr.OUTCOME_CODE,fcr.CPU_SECONDS,fcr.LOGICAL_IOS,fcr.PHYSICAL_IOS,fcr.LOGFILE_NAME,fcr.LOGFILE_NODE_NAME,
fcr.OUTFILE_NAME,fcr.OUTFILE_NODE_NAME,fcr.ARGUMENT_TEXT,fcr.ARGUMENT1,fcr.ARGUMENT2,fcr.ARGUMENT3,fcr.ARGUMENT4,
fcr.ARGUMENT5,fcr.ARGUMENT6,fcr.ARGUMENT7,fcr.ARGUMENT8,fcr.ARGUMENT9,fcr.ARGUMENT10,fcr.ARGUMENT11,
fcr.ARGUMENT12,fcr.ARGUMENT13,fcr.ARGUMENT14,fcr.ARGUMENT15,fcr.ARGUMENT16,fcr.ARGUMENT17,fcr.ARGUMENT18,
fcr.ARGUMENT19,fcr.ARGUMENT20,fcr.ARGUMENT21,fcr.ARGUMENT22,fcr.ARGUMENT23,fcr.ARGUMENT24,fcr.ARGUMENT25,
fcr.CRM_THRSHLD,fcr.CRM_TSTMP,fcr.CRITICAL,fcr.REQUEST_TYPE,fcr.ORACLE_PROCESS_ID,fcr.ORACLE_SESSION_ID,
fcr.OS_PROCESS_ID,fcr.PRINT_JOB_ID,fcr.OUTPUT_FILE_TYPE,fcr.RELEASE_CLASS_APP_ID,fcr.RELEASE_CLASS_ID,
fcr.STALE_DATE,fcr.CANCEL_OR_HOLD,fcr.NOTIFY_ON_PP_ERROR,fcr.NLS_COMPLIANT,fcr.CD_ID,fcr.REQUEST_LIMIT,
fcr.CRM_RELEASE_DATE,fcr.POST_REQUEST_STATUS,fcr.COMPLETION_CODE,fcr.INCREMENT_DATES,fcr.RESTART,fcr.ENABLE_TRACE,
fcr.RESUB_COUNT,fcr.NLS_CODESET,fcr.OFILE_SIZE,fcr.LFILE_SIZE,fcr.STALE,fcr.SECURITY_GROUP_ID,
fcr.RESOURCE_CONSUMER_GROUP,fcr.EXP_DATE,fcr.QUEUE_APP_ID,fcr.QUEUE_ID,fcr.OPS_INSTANCE,fcr.INTERIM_STATUS_CODE,
fcr.ROOT_REQUEST_ID,fcr.ORIGIN,fcr.NLS_NUMERIC_CHARACTERS,'fnd_concurrent_requests' as TABLENAME,
fl.login_name,fu.user_name,fat.application_name,fcpt.user_concurrent_program_name"
# fcr.PP_START_DATE,fcr.PP_END_DATE,fcr.ORG_ID,fcr.RUN_NUMBER, - those columns are not in 11.5.9 version
TABLE_DESC10="fcr.REQUEST_ID,fcr.LAST_UPDATE_DATE,fcr.LAST_UPDATED_BY,fcr.LAST_UPDATE_LOGIN,fcr.REQUEST_DATE,fcr.REQUESTED_BY,
fcr.PHASE_CODE,fcr.STATUS_CODE,fcr.PRIORITY_REQUEST_ID,fcr.PRIORITY,fcr.REQUESTED_START_DATE,fcr.HOLD_FLAG,
fcr.ENFORCE_SERIALITY_FLAG,fcr.SINGLE_THREAD_FLAG,fcr.HAS_SUB_REQUEST,fcr.IS_SUB_REQUEST,fcr.IMPLICIT_CODE,
fcr.UPDATE_PROTECTED,fcr.QUEUE_METHOD_CODE,fcr.ARGUMENT_INPUT_METHOD_CODE,fcr.ORACLE_ID,fcr.PROGRAM_APPLICATION_ID,
fcr.CONCURRENT_PROGRAM_ID,fcr.RESPONSIBILITY_APPLICATION_ID,fcr.RESPONSIBILITY_ID,fcr.NUMBER_OF_ARGUMENTS,
fcr.NUMBER_OF_COPIES,fcr.SAVE_OUTPUT_FLAG,fcr.NLS_LANGUAGE,fcr.NLS_TERRITORY,fcr.PRINTER,fcr.PRINT_STYLE,
fcr.PRINT_GROUP,fcr.REQUEST_CLASS_APPLICATION_ID,fcr.CONCURRENT_REQUEST_CLASS_ID,fcr.PARENT_REQUEST_ID,
fcr.CONC_LOGIN_ID,fcr.LANGUAGE_ID,replace(fcr.DESCRIPTION,CHR(10),' ') as DESCRIPTION,
replace(fcr.REQ_INFORMATION,CHR(10),' ') as REQ_INFORMATION,fcr.RESUBMIT_INTERVAL,
fcr.RESUBMIT_INTERVAL_UNIT_CODE,fcr.RESUBMIT_INTERVAL_TYPE_CODE,fcr.RESUBMIT_TIME,fcr.RESUBMIT_END_DATE,
fcr.RESUBMITTED,fcr.CONTROLLING_MANAGER,fcr.ACTUAL_START_DATE,fcr.ACTUAL_COMPLETION_DATE,
replace(fcr.COMPLETION_TEXT,CHR(10),' ') as COMPLETION_TEXT,replace(fcr.OUTCOME_PRODUCT,CHR(10),' ') as OUTCOME_PRODUCT,
fcr.OUTCOME_CODE,fcr.CPU_SECONDS,fcr.LOGICAL_IOS,fcr.PHYSICAL_IOS,fcr.LOGFILE_NAME,fcr.LOGFILE_NODE_NAME,
fcr.OUTFILE_NAME,fcr.OUTFILE_NODE_NAME,fcr.ARGUMENT_TEXT,fcr.ARGUMENT1,fcr.ARGUMENT2,fcr.ARGUMENT3,fcr.ARGUMENT4,
fcr.ARGUMENT5,fcr.ARGUMENT6,fcr.ARGUMENT7,fcr.ARGUMENT8,fcr.ARGUMENT9,fcr.ARGUMENT10,fcr.ARGUMENT11,
fcr.ARGUMENT12,fcr.ARGUMENT13,fcr.ARGUMENT14,fcr.ARGUMENT15,fcr.ARGUMENT16,fcr.ARGUMENT17,fcr.ARGUMENT18,
fcr.ARGUMENT19,fcr.ARGUMENT20,fcr.ARGUMENT21,fcr.ARGUMENT22,fcr.ARGUMENT23,fcr.ARGUMENT24,fcr.ARGUMENT25,
fcr.CRM_THRSHLD,fcr.CRM_TSTMP,fcr.CRITICAL,fcr.REQUEST_TYPE,fcr.ORACLE_PROCESS_ID,fcr.ORACLE_SESSION_ID,
fcr.OS_PROCESS_ID,fcr.PRINT_JOB_ID,fcr.OUTPUT_FILE_TYPE,fcr.RELEASE_CLASS_APP_ID,fcr.RELEASE_CLASS_ID,
fcr.STALE_DATE,fcr.CANCEL_OR_HOLD,fcr.NOTIFY_ON_PP_ERROR,fcr.NLS_COMPLIANT,fcr.CD_ID,fcr.REQUEST_LIMIT,
fcr.CRM_RELEASE_DATE,fcr.POST_REQUEST_STATUS,fcr.COMPLETION_CODE,fcr.INCREMENT_DATES,fcr.RESTART,fcr.ENABLE_TRACE,
fcr.RESUB_COUNT,fcr.NLS_CODESET,fcr.OFILE_SIZE,fcr.LFILE_SIZE,fcr.STALE,fcr.SECURITY_GROUP_ID,
fcr.RESOURCE_CONSUMER_GROUP,fcr.EXP_DATE,fcr.QUEUE_APP_ID,fcr.QUEUE_ID,fcr.OPS_INSTANCE,fcr.INTERIM_STATUS_CODE,
fcr.ROOT_REQUEST_ID,fcr.ORIGIN,fcr.NLS_NUMERIC_CHARACTERS,fcr.PP_START_DATE,fcr.PP_END_DATE,fcr.ORG_ID,fcr.RUN_NUMBER,
'fnd_concurrent_requests' as TABLENAME,fl.login_name,fu.user_name,fat.application_name,fcpt.user_concurrent_program_name"
TABLE_HEAD="*"
COL_TIME="actual_start_date"
GETHEADER="YES"
TIMESTAMPNAME="FND_CONCURRENT_REQUESTS"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';
COLUMN PHASE_CODE FORMAT A12;
COLUMN STATUS_CODE FORMAT A12;
COLUMN REQUESTED_START_DATE FORMAT A22;
COLUMN HOLD_FLAG FORMAT A10;
COLUMN ENFORCE_SERIALITY_FLAG FORMAT A24;
COLUMN SINGLE_THREAD_FLAG FORMAT A20;
COLUMN HAS_SUB_REQUEST FORMAT A17;
COLUMN IS_SUB_REQUEST FORMAT A15;
COLUMN IMPLICIT_CODE FORMAT A14;
COLUMN UPDATE_PROTECTED FORMAT A16;
COLUMN QUEUE_METHOD_CODE FORMAT A18; 
COLUMN ARGUMENT_INPUT_METHOD_CODE FORMAT A27; 
COLUMN SAVE_OUTPUT_FLAG FORMAT A17; 
COLUMN NLS_COMPLIANT FORMAT A14; 
COLUMN PRINT_GROUP FORMAT A12; 
COLUMN RESUBMIT_TIME FORMAT A20; 
COLUMN RESUBMITTED FORMAT A12; 
COLUMN ACTUAL_COMPLETION_DATE FORMAT A24; 
COLUMN CRM_TSTMP FORMAT A20; 
COLUMN CRITICAL FORMAT A9; 
COLUMN REQUEST_TYPE FORMAT A14; 
COLUMN OUTPUT_FILE_TYPE FORMAT A18; 
COLUMN REQUEST_LIMIT FORMAT A14; 
COLUMN CANCEL_OR_HOLD FORMAT A14;
COLUMN REQUEST_LIMIT FORMAT A14; 
COLUMN POST_REQUEST_STATUS FORMAT A20; 
COLUMN INCREMENT_DATES FORMAT A20; 
COLUMN RESTART FORMAT A8; 
COLUMN ENABLE_TRACE FORMAT A14; 
COLUMN STALE FORMAT A6;
COLUMN INTERIM_STATUS_CODE FORMAT A20; 
COLUMN ORIGIN FORMAT A7; 
COLUMN NLS_NUMERIC_CHARACTERS FORMAT A24; 
COLUMN COMPLETION_TEXT FORMAT A2400;"

#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh

