#!/bin/sh

######################################################################
# export all envinroment variables which are needed for getoradblogs2.sh back-end actuator script     #
######################################################################
export_env_variables()
{
    export PROPSFILE
    export CEA_GENACT_FUNCLIB
    export CEA_GENACT_DEBUG_LOG

    export ORACLE_SID
    export ORA_INSTANCE
    export ORA_USER
    export ORA_PWD
    export ORACLE_HOME 

    export TEMPFILE

    export TABLE_NAME
    export TABLE_NAME9
    export TABLE_NAME10
    export TABLE_DESC
    export TABLE_DESC9
    export TABLE_DESC10
    export TABLE_HEAD
    export TABLE_HEAD9
    export TABLE_HEAD10
    export COL_TIME
    export COL_TIME9
    export COL_TIME10
    export LINE_SIZE
    export GETHEADER
    export PARAM_OUTPUT
    export NOTIMESTAMP
    export TIMESTAMPNAME
    export NOLINESCHECK
}
# Source our function library. It contains generic functions. 
. $CEA_GENACT_FUNCLIB || exit 1

#######################################################
# Usage: err_exit <exit-code> [exit-message]
#######################################################
err_exit()
{
  debug $2
  debug "Warning: Processing finished with error \"$1\". "
  exit 0
}

CEA_GENACT_DEBUG_LOG="../log/cea_genact_debug_log.log"

if [ -z "${PROPSFILE}" ]; then err_exit 1 "Properties file must be specified!"; fi
CEA_GENACT_DEBUG_LOG="../log/${PROPSFILE}.log"
debug script $0 is running

if [ -z "${OPTION2}" ]; then err_exit 1 "Option #2 'Oracle Instance' must be specified!"; fi
if [ -z "${OPTION3}" ]; then err_exit 1 "Option #3 'Oracle User Name' must be specified!"; fi
if [ -z "${OPTION5}" ]; then err_exit 1 "Option #5 'Oracle Home Path' must be specified!"; fi

# Parameters needed for oracle access
ORACLE_SID="${OPTION2}"
ORA_INSTANCE="@${OPTION2}"
ORA_USER="${OPTION3}"
ORA_PWD="${OPTION4}"
ORACLE_HOME="${OPTION5}"

# Parameters needed for getoradblogs2.sh
TEMPFILE="${TEMPFILE3}"
if [ -f "$TEMPFILE" ]; then rm "$TEMPFILE"; fi

# Parameters needed for data acquisition
TABLE_NAME="applsys.fnd_login_responsibilities flr LEFT OUTER JOIN applsys.fnd_logins fl ON flr.login_id=fl.login_id 
LEFT OUTER JOIN applsys.fnd_user fu ON fu.user_id=fl.user_id 
LEFT OUTER JOIN applsys.fnd_responsibility_tl frt ON flr.responsibility_id=frt.responsibility_id and 
flr.resp_appl_id=frt.application_id and frt.language in (select LANGUAGE_CODE from APPLSYS.FND_LANGUAGES where INSTALLED_FLAG = 'B') 
LEFT OUTER JOIN applsys.fnd_application_tl fat ON flr.resp_appl_id=fat.application_id and fat.language in 
(select LANGUAGE_CODE from APPLSYS.FND_LANGUAGES where INSTALLED_FLAG = 'B')"
TABLE_DESC="flr.*, 'fnd_login_responsibilities' as TABLENAME, 
fl.session_number, fl.pid, fl.login_name, fu.user_name, frt.responsibility_name, fat.application_name"
TABLE_HEAD="*"
COL_TIME="flr.start_time"
GETHEADER="YES"
TIMESTAMPNAME="FND_LOGIN_RESPONSIBILITIES"
PARAM_OUTPUT="SET COLSEP ';';
SET HEA ON;
SET HEADSEP ON;
SET HEADS ';';
alter session set nls_timestamp_format = 'YYYY-MM-DD HH24:MI:SS';
alter session set nls_date_format = 'YYYY-MM-DD HH24:MI:SS';"
NOLINESCHECK=""

#call back-end script to get data from Oracle DB
export_env_variables
../bin/getoradblogs2.sh


